# -*- coding: utf-8 -*-
"""
Global configuration file for TG2-specific settings in classifieds.

This file complements development/deployment.ini.

"""

from tg.configuration import AppConfig, Bunch

import classifieds
from classifieds import model
from classifieds.lib import app_globals, helpers

class ClassifiedsConfig(AppConfig):
    
    def setup_routes(self):
        """Customize routing"""
        from tg import config
        from routes import Mapper
        dir = config['pylons.paths']['controllers']
        map = Mapper(directory=dir,
                     always_scan=config['debug'])
        # Defining our custom routes:
        map.connect('/{action}/{classified:\d+}',
                    controller='root')
        # Required by TurboGears:
        map.connect('*url', controller='root', 
                    action='routes_placeholder')
        config['routes.map'] = map

base_config = ClassifiedsConfig()
base_config.renderers = []

base_config.package = classifieds

#Set the default renderer
base_config.default_renderer = 'genshi'
base_config.renderers.append('genshi')
# if you want raw speed and have installed chameleon.genshi
# you should try to use this renderer instead.
# warning: for the moment chameleon does not handle i18n translations
#base_config.renderers.append('chameleon_genshi')

#Configure the base SQLALchemy Setup
base_config.use_sqlalchemy = True
base_config.model = classifieds.model
base_config.DBSession = classifieds.model.DBSession

# Configure the authentication backend
#base_config.auth_backend = 'sqlalchemy'
base_config.sa_auth.dbsession = model.DBSession
# what is the class you want to use to search for users in the database
base_config.sa_auth.user_class = model.User
# what is the class you want to use to search for groups in the database
base_config.sa_auth.group_class = model.Group
# what is the class you want to use to search for permissions in the database
base_config.sa_auth.permission_class = model.Permission

# override this if you would like to provide a different who plugin for
# managing login and logout of your application
base_config.sa_auth.form_plugin = None

# You may optionally define a page where you want users to be redirected to
# on login:
base_config.sa_auth.post_login_url = '/post_login'

# You may optionally define a page where you want users to be redirected to
# on logout:
base_config.sa_auth.post_logout_url = '/post_logout'
