# -*- coding: utf-8 -*-
"""WSGI middleware initialization for the classifieds application."""

from classifieds.config.app_cfg import base_config
from classifieds.config.environment import load_environment
from classifieds.config.auth import add_auth

__all__ = ['make_app']

# Use base_config to setup the necessary PasteDeploy application factory. 
# make_base_app will wrap the TG2 app with all the middleware it needs. 
make_base_app = base_config.setup_tg_wsgi_app(load_environment)


def make_app(global_conf, full_stack=True, **app_conf):
    """
    Set classifieds up with the settings found in the PasteDeploy configuration
    file used.
    
    :param global_conf: The global settings for classifieds (those
        defined under the ``[DEFAULT]`` section).
    :type global_conf: dict
    :param full_stack: Should the whole TG2 stack be set up?
    :type full_stack: str or bool
    :return: The classifieds application with all the relevant middleware
        loaded.
    
    This is the PasteDeploy factory for the classifieds application.
    
    ``app_conf`` contains all the application-specific settings (those defined
    under ``[app:main]``.
    
    Please note that **all the argument values are strings**. If you want to
    convert them into boolean, for example, you should use the
    :func:`paste.deploy.converters.asbool` function, as in::
    
        from paste.deploy.converters import asbool
        
        setting = asbool(global_conf.get('the_setting'))
    
    """
    app = make_base_app(global_conf, full_stack=True, **app_conf)
    
    # Wrap your base TurboGears 2 application with custom middleware here
    app = add_auth(app)
    return app
